pub async fn run_now(conn: &mut PgConnection, phase: &str) -> ModelResult<()>Expand description
Makes the phase due now; the phase loop picks it up on its next next_run_at check.
pub async fn run_now(conn: &mut PgConnection, phase: &str) -> ModelResult<()>Makes the phase due now; the phase loop picks it up on its next next_run_at check.